Features — Flower 1.0.1 documentation

# Features

- Real-time monitoring using Celery Events

  > - Task progress and history

  > - Ability to show task details (arguments, start time, runtime, and more)

  > - Graphs and statistics

- Remote Control

  > - View worker status and statistics

  > - Shutdown and restart worker instances

  > - Control worker pool size and autoscale settings

  > - View and modify the queues a worker instance consumes from

  > - View currently running tasks

  > - View scheduled tasks (ETA/countdown)

  > - View reserved and revoked tasks

  > - Apply time and rate limits

  > - Configuration viewer

  > - Revoke or terminate tasks

- Broker monitoring

  > - View statistics for all Celery queues

  > - Queue length graphs

- HTTP API

- Basic Auth, GitHub OAuth2 and Google OpenID authentication

- Prometheus integration